@@ -1,3 +1,6 @@
+if (!require (ts, quietly=TRUE))
+  stop (paste("Package ts is needed (It should be installed automatically\n",
+              "      for version 0.65.0 and later). Stopping"))
 nino3 <- ts(c(
 23.97,
 24.51,
@@ -1198,5 +1201,4 @@ nino3.4 <- ts(c(
 25.70,
 25.63),
 start=c(1950,1), end=c(1999,10), frequency=12)
-require(ts)
 nino <- ts.union (nino3, nino3.4)
